--- a/dll.h
+++ b/dll.h
@@ -43,7 +43,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-/*#include <cassert>*/
+#include <assert.h>
 #include <math.h>
 
 /*#define STAT*/	/* Define STAT to generate a statistics log, stat.txt */
